@@ -1,23 +1,37 @@
-use indexmap::IndexMap;
+use std::collections::{BTreeMap, HashMap};
+
 use serde::{
     ser::{SerializeMap, SerializeStruct},
     Serialize, Serializer,
 };
 
 use crate::registry::{
-    MetaAPI, MetaInfo, MetaPath, MetaResponses, MetaSchema, MetaSchemaRef, MetaServer, MetaTag,
-    Registry,
+    MetaApi, MetaInfo, MetaPath, MetaResponses, MetaSchema, MetaSchemaRef, MetaSecurityScheme,
+    MetaServer, Registry,
 };
 
 const OPENAPI_VERSION: &str = "3.0.0";
 
-struct PathMap<'a>(&'a [MetaAPI]);
+impl<'a> Serialize for MetaSchemaRef {
+    fn serialize<S: Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
+        match self {
+            MetaSchemaRef::Inline(schema) => schema.serialize(serializer),
+            MetaSchemaRef::Reference(name) => {
+                let mut s = serializer.serialize_struct("MetaSchemaRef", 1)?;
+                s.serialize_field("$ref", &format!("#/components/schemas/{}", name))?;
+                s.end()
+            }
+        }
+    }
+}
+
+struct PathMap<'a>(&'a [MetaApi]);
 
 impl<'a> Serialize for PathMap<'a> {
     fn serialize<S: Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
         let mut s = serializer.serialize_map(Some(self.0.len()))?;
         for api in self.0 {
-            for path in api.paths {
+            for path in &api.paths {
                 s.serialize_entry(path.path, path)?;
             }
         }
@@ -29,7 +43,7 @@ impl Serialize for MetaPath {
     fn serialize<S: Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
         let mut s = serializer.serialize_map(None)?;
 
-        for operation in self.operations {
+        for operation in &self.operations {
             s.serialize_entry(&operation.method.to_string().to_lowercase(), operation)?;
         }
 
@@ -37,28 +51,10 @@ impl Serialize for MetaPath {
     }
 }
 
-impl Serialize for MetaSchemaRef {
-    fn serialize<S: Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
-        match self {
-            MetaSchemaRef::Inline(data_type) => {
-                let mut s = serializer.serialize_struct("Schema", 2)?;
-                s.serialize_field("type", data_type.ty)?;
-                s.serialize_field("format", &data_type.format)?;
-                s.end()
-            }
-            MetaSchemaRef::Reference(name) => {
-                let mut s = serializer.serialize_struct("Schema", 1)?;
-                s.serialize_field("$ref", &format!("#/components/schemas/{}", name))?;
-                s.end()
-            }
-        }
-    }
-}
-
 impl Serialize for MetaResponses {
     fn serialize<S: Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
         let mut s = serializer.serialize_map(None)?;
-        for resp in self.responses {
+        for resp in &self.responses {
             match resp.status {
                 Some(status) => s.serialize_entry(&format!("{}", status), resp)?,
                 None => s.serialize_entry("default", resp)?,
@@ -71,8 +67,7 @@ impl Serialize for MetaResponses {
 pub(crate) struct Document<'a> {
     pub(crate) info: Option<&'a MetaInfo>,
     pub(crate) servers: &'a [MetaServer],
-    pub(crate) apis: &'a [MetaAPI],
-    pub(crate) tags: &'a [MetaTag],
+    pub(crate) apis: &'a [MetaApi],
     pub(crate) registry: &'a Registry,
 }
 
@@ -80,7 +75,9 @@ impl<'a> Serialize for Document<'a> {
     fn serialize<S: Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
         #[derive(Serialize)]
         struct Components<'a> {
-            schemas: &'a IndexMap<&'static str, MetaSchema>,
+            schemas: &'a HashMap<&'static str, MetaSchema>,
+            #[serde(rename = "securitySchemes")]
+            security_schemes: &'a BTreeMap<&'static str, MetaSecurityScheme>,
         }
 
         let mut s = serializer.serialize_struct("OpenAPI", 6)?;
@@ -88,12 +85,13 @@ impl<'a> Serialize for Document<'a> {
         s.serialize_field("openapi", OPENAPI_VERSION)?;
         s.serialize_field("info", &self.info)?;
         s.serialize_field("servers", self.servers)?;
-        s.serialize_field("tags", self.tags)?;
-        s.serialize_field("paths", &PathMap(&self.apis))?;
+        s.serialize_field("tags", &self.registry.tags)?;
+        s.serialize_field("paths", &PathMap(self.apis))?;
         s.serialize_field(
             "components",
             &Components {
                 schemas: &self.registry.schemas,
+                security_schemes: &self.registry.security_schemes,
             },
         )?;
 
